@@ -19,5 +19,8 @@ eval "$(tmp/homebrew/bin/brew shellenv)"
 brew update --force --quiet
 chmod -R go-w "$(brew --prefix)/share/zsh"
 
+git config user.name "cloudflare-warp-bot"
+git config user.email "warp-bot@cloudflare.com"
+
 # bump formula pr
 brew bump-formula-pr cloudflared --version="$VERSION"
